---
title: <span class="badge object-type-disjunction"></span> Expr
---
# <span class="badge object-type-disjunction"></span> Expr

## Definition

```python
Expr: typing.TypeAlias = typing.Union[expr.TypeMath, expr.TypeReduce, expr.TypeResample, expr.TypeClassicConditions, expr.TypeThreshold, expr.TypeSql]
```
